FrameGrabberInterfacesRefactor2 {#master}
-------------------------------

## Libraries

### `dev`

* All classes and vocabs moved in framegrabber_protocol library were removed.
  This is an API break, but nobody should be using these outside of YARP.
